@@ -1,10 +1,15 @@
 from dataclasses import dataclass
 from difflib import unified_diff
 from pathlib import Path
-from typing import Iterable, Optional, Type
+from typing import (
+    Iterable,
+    Optional,
+    Tuple,
+    Type,
+)
 
 from click import (
-    Option,
+    Argument,
     Parameter,
     Path as PathType,
     echo,
@@ -33,24 +38,39 @@ class DiffPlugin(Plugin):
         """
         left_tree = self.blob.as_tree()
 
-        names = left_tree.keys() | right_tree.keys()
-
-        for name in names:
-            left = left_tree.get(name)
-            right = right_tree.get(name)
-
-            for item in self.diff(name, left, right):
+        for path, left, right in self.iter_blobs(left_tree, right_tree):
+            for item in self.diff(path, left, right):
                 echo(item.strip("\n"))
 
-    def diff(self, name: str, left: Optional[Blob], right: Optional[Blob]) -> Iterable[str]:
+    def iter_blobs(self, left_tree: Tree, right_tree: Tree) -> Iterable[Tuple[str, Optional[Blob], Optional[Blob]]]:
+        left: Optional[Blob]
+        right: Optional[Blob]
+
+        if len(right_tree.blobs) == 1 and len(left_tree.blobs) == 1:
+            # special case for single file comparison
+            left = next(iter(left_tree.blobs.values()))
+            right = next(iter(right_tree.blobs.values()))
+
+            yield "file", left, right
+        else:
+            # directory comparison
+            paths = left_tree.blobs.keys() | right_tree.blobs.keys()
+
+            for path in paths:
+                left = left_tree.blobs.get(path)
+                right = right_tree.blobs.get(path)
+
+                yield str(path), left, right
+
+    def diff(self, path: str, left: Optional[Blob], right: Optional[Blob]) -> Iterable[str]:
         """
         Produce a single file diff, assuming text data.
 
         """
         left_lines = left.read().decode("utf-8").splitlines() if left else []
         right_lines = right.read().decode("utf-8").splitlines() if right else []
-        left_name = f"{name} - original"
-        right_name = f"{name} - generated"
+        left_name = f"{path} - original"
+        right_name = f"{path} - generated"
 
         lines = unified_diff(left_lines, right_lines, left_name, right_name, lineterm="")
 
@@ -66,13 +86,14 @@ class DiffPlugin(Plugin):
 
     @classmethod
     def iter_parameters(cls: Type["DiffPlugin"]) -> Iterable[Parameter]:
-        yield Option(
+        yield Argument(
             [
-                "--path",
+                "path",
             ],
             required=True,
             type=PathType(
                 allow_dash=False,
+                # TODO: support directories
                 dir_okay=False,
                 exists=True,
                 file_okay=True,
@@ -94,6 +115,5 @@ class DiffPlugin(Plugin):
         return cls(
             blob=FileBlob.open(
                 path=path,
-                name="file",
             ),
         )
